@@ -88,19 +88,19 @@ def update_k_mers_in_special_cases(cur_k_mers, RL, log, silent=False):
     if options_storage.auto_K_allowed():
         if RL >= 250:
             if not silent:
-                support.warning("Default k-mer sizes were set to %s because estimated "
-                                "read length (%d) is equal to or greater than 250" % (str(options_storage.K_MERS_250), RL), log)
+                log.info("Default k-mer sizes were set to %s because estimated "
+                         "read length (%d) is equal to or greater than 250" % (str(options_storage.K_MERS_250), RL))
             return options_storage.K_MERS_250
         if RL >= 150:
             if not silent:
-                support.warning("Default k-mer sizes were set to %s because estimated "
-                                "read length (%d) is equal to or greater than 150" % (str(options_storage.K_MERS_150), RL), log)
+                log.info("Default k-mer sizes were set to %s because estimated "
+                         "read length (%d) is equal to or greater than 150" % (str(options_storage.K_MERS_150), RL), log)
             return options_storage.K_MERS_150
     if RL <= max(cur_k_mers):
         new_k_mers = [k for k in cur_k_mers if k < RL]
         if not silent:
-            support.warning("K-mer sizes were set to %s because estimated "
-                            "read length (%d) is less than %d" % (str(new_k_mers), RL, max(cur_k_mers)), log)
+            log.info("K-mer sizes were set to %s because estimated "
+                     "read length (%d) is less than %d" % (str(new_k_mers), RL, max(cur_k_mers)), log)
         return new_k_mers
     return cur_k_mers
 
@@ -201,6 +201,7 @@ def prepare_config_scaffold_correction(filename, cfg, log, saves_dir, K):
     #todo
     process_cfg.substitute_params(filename, subst_dict, log)
 
+
 def run_scaffold_correction(configs_dir, execution_home, cfg, log, latest, K):
     data_dir = os.path.join(cfg.output_dir, "SCC", "K%d" % K)
     saves_dir = os.path.join(data_dir, 'saves')
@@ -232,6 +233,7 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
     if not isinstance(cfg.iterative_K, list):
         cfg.iterative_K = [cfg.iterative_K]
     cfg.iterative_K = sorted(cfg.iterative_K)
+    used_K = []
 
     # checking and removing conflicting K-mer directories
     if options_storage.restart_from:
@@ -249,7 +251,7 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
             k_to_delete = []
             for id, k in enumerate(needed_K):
                 if len(processed_K) == id:
-                    if processed_K[-1] == original_K[-1]: # the last K in the original run was processed in "last_one" mode
+                    if processed_K[-1] == original_K[-1]:  # the last K in the original run was processed in "last_one" mode
                         k_to_delete = [original_K[-1]]
                     break
                 if processed_K[id] != k:
@@ -272,8 +274,10 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
     K = cfg.iterative_K[0]
     if len(cfg.iterative_K) == 1:
         run_iteration(configs_dir, execution_home, cfg, log, K, None, True)
+        used_K.append(K)
     else:
         run_iteration(configs_dir, execution_home, cfg, log, K, None, False)
+        used_K.append(K)
         if options_storage.stop_after == "k%d" % K:
             finished_on_stop_after = True
         else:
@@ -290,6 +294,7 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
                                         "Rerunning for the first value of K (%d) with Repeat Resolving" %
                                         (cfg.iterative_K[1], RL, cfg.iterative_K[0]), log)
                     run_iteration(configs_dir, execution_home, cfg, log, cfg.iterative_K[0], None, True)
+                    used_K.append(cfg.iterative_K[0])
                     K = cfg.iterative_K[0]
             else:
                 rest_of_iterative_K = cfg.iterative_K
@@ -299,6 +304,7 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
                     count += 1
                     last_one = count == len(cfg.iterative_K) or (rest_of_iterative_K[count] + 1 > RL)
                     run_iteration(configs_dir, execution_home, cfg, log, K, prev_K, last_one)
+                    used_K.append(K)
                     prev_K = K
                     if last_one:
                         break
@@ -354,8 +360,6 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
             if not os.path.isfile(cfg.result_scaffolds_paths) or not options_storage.continue_mode:
                 shutil.copyfile(os.path.join(latest, "scaffolds.paths"), cfg.result_scaffolds_paths)
 
-
-
     if cfg.developer_mode:
         # saves
         saves_link = os.path.join(os.path.dirname(cfg.result_contigs), "saves")
@@ -368,4 +372,4 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
     if os.path.isdir(cfg.tmp_dir):
         shutil.rmtree(cfg.tmp_dir)
 
-    return latest
+    return used_K
